# nsvision
nsvision is a python library and commandline tool build for simplifying image preprocessing / postprocessing.
We have optimised the library for reducing the code work while working on image / video processing for data science related work.

## Installation:
```bash
pip install nsvision
```

## Documentation:

Refer [nsvision](https://nsvision.nsemble.ai) for complete documentation<br>

Read the docs link: [click here](https://nsvision.readthedocs.org)
